API docs for “spamfighter.core.rules”

# Module s.c.rules

Part of spamfighter.core View Source

Обслуживание правил для анализа сообщений.

Class | DuplicateRuleError | Правило с таким именем уже было зарегистриовано.
Class | RuleNotFoundError | Правило с таким именем не найдено.
Class | RulesFactory | Фабрика правил анализа сообщений. Регистрирует правила
Function | ruleTrue | Правило, которое всегда возвращает истину.
Function | ruleFalse | Правило, которое всегда возвращает ложь.

def ruleTrue(domain, message): (source)
Правило, которое всегда возвращает истину.

def ruleFalse(domain, message): (source)
Правило, которое всегда возвращает ложь.